# cdcdeaths
cdcdeaths is a PyPI package for displaying the number of deaths in the US due to COVID-19 by age groups.
cdcdeaths can scrape the latest data from cdc.
result.png file will be generated.

# how to install cdcdeaths
On WSL on Windows, MacOS, and Linux operating systems, run the following command to install it:

$ pip install cdcdeaths

On Windows 11 or 10,

$ pip install cdcdeaths --force-reinstall --no-cache-dir --no-binary :all:

# how to run cdcdeaths

$ cdcdeaths

<img src='https://github.com/ytakefuji/cdcdeaths/raw/main/result.png' width=640 height=480>

